@@ -256,7 +256,7 @@ SMR.table <- function(data, group.var, obs.var, pred.var, digits = 5, use.label
   } else {
     Levels <- c(NA, unname(unlist(sapply(data[ , group.var], levels))))
   }
-  x <- data.frame(Variables, Levels)
+  x <- data.frame(Variables, Levels, stringsAsFactors = TRUE)
   x$N <- NA
   x$Observed <- NA
   x$Expected <- NA
@@ -479,3 +479,4 @@ forest.SMR <- function(x,
   do.call(text, SMR.head.arg)
 }
 
+
